use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Aas
Adam
Alders
Alders'
Alex
Alexey
Andreas
Bill
Bron
Burke
Chrysostomos
DAVIDRW
Daniel
Date
David
Denaxas
FWILES
Father
Finch
Froehlich
Gavin
Gisle
Gondwana
Graeme
Grossmann
HTTP
Hanak
Hans
Hay
Hedlund
Hukins
Ian
Jacob
Kapranoff
Karaban
Kennedy
Kilgore
Koenig
Lipcon
Ludlam
MARKSTOS
Mann
Mark
Mike
Olaf
Ondrej
Peter
Peters
Philip
Rabbitson
Rezic
Robert
Rolf
Schilli
Sean
Sjogren
Skytta
Slaven
Spiros
Steve
SteveHay
Stone
Stosberg
TZ
Thompson
Todd
Tom
Tony
Toru
Tourbin
Ville
Wheeler
YYYY
Yamaguchi
Yuri
Zefram
aas
adamk
amir
amire80
andreas
asjo
at
brong
david
davidrw
denaxas
dot
gisle
github
gpeters
hfroehlich
iank
jefflee
john9art
ka
lib
ludlam
mark
mschilli
murphy
olaf
ondrej
phrstbrn
pnull
rg
ribasushi
ruff
sasao
sburke
shaohua
slaven
sprout
srezic
talby
tech
todd
tom
uid39246
ville
waif
wfmann
zefram
zigorou
